@@ -129,18 +129,18 @@ class Client(object):
 
             response = requests.post(url, data=payload, files=files, auth=(self.username, self.password), headers=self.headers, verify=False)
             if verbose:
-                print "POSTED Payload of ", payload
-                print "POSTED file list of ", files
-                print "\n"
-                print "POST Status = %d" % ( response.status_code)
-                print "Response Content = %s" % (response.text)
+                print("POSTED Payload of ", payload)
+                print("POSTED file list of ", files)
+                print("\n")
+                print("POST Status = %d" % ( response.status_code))
+                print("Response Content = %s" % (response.text))
 
             if response.status_code == 200:
                 return JobStatus(self, xml=ET.fromstring(response.text.encode('utf-8')))
             else:
                 self.__raiseException__(response)
         finally:
-            for param, openfile in files.iteritems():
+            for param, openfile in files.items():
                 openfile.close
                 
 
@@ -225,7 +225,7 @@ class Client(object):
         """ Returns xml text or throws a CipresError """
         r = requests.get(url, auth=(self.username, self.password), verify=False, headers = self.headers, stream=stream);
         if verbose:
-            print "GET %s\nStatus = %d\nText:%s\n" % (url, r.status_code, r.text)
+            print("GET %s\nStatus = %d\nText:%s\n" % (url, r.status_code, r.text))
         if r.status_code != 200:
             self.__raiseException__(r);
         return r
@@ -236,7 +236,7 @@ class Client(object):
         if r.status_code != 200 and r.status_code != 204 and r.status_code != 202:
             self.__raiseException__(r)
         if verbose:
-            print "DELETE %s\nStatus = %d\nContent = %s" % (url, r.status_code, r.text)
+            print("DELETE %s\nStatus = %d\nContent = %s" % (url, r.status_code, r.text))
         return r
 
     def __parseJobList__(self, text):
@@ -304,7 +304,7 @@ class JobStatus(object):
         """ A debugging method to dump some of the content of this object to stdout """
 
         if not self.jobHandle and self.commandline:
-            print "Submission validated.  Commandline is: '%s'" % (self.commandline)
+            print("Submission validated.  Commandline is: '%s'" % (self.commandline))
             return
 
         str = "Job=%s" % (self.jobHandle)
@@ -315,10 +315,10 @@ class JobStatus(object):
                 str += ", finished, results are at %s" % (self.resultsUrl)
         else:
             str += ", not finished, stage=%s" % (self.jobStage)
-        print str
+        print(str)
         if messages:
             for m in self.messages:
-                print "\t%s" % (m)
+                print("\t%s" % (m))
             
 
     def update(self):
@@ -379,7 +379,7 @@ class ResultFile(object):
         path = os.path.join(directory, self.name)
 
         if verbose:
-            print "downloading from %s to %s" % (self.url, path)
+            print("downloading from %s to %s" % (self.url, path))
         r = self.client.__doGet__(self.url, stream=True)
         with open(path, 'wb') as outfile:
             shutil.copyfileobj(r.raw, outfile)
@@ -413,7 +413,7 @@ class Application(object):
         try:
             with open(confFile) as infile:
                 self.props.load(infile)
-        except IOError, e:
+        except IOError as e:
             pass
 
         confFile = os.path.join(os.path.expanduser("~"), "pycipres.conf");
@@ -421,7 +421,7 @@ class Application(object):
         try:
             with open(confFile) as infile:
                 self.props.load(infile)
-        except IOError, e:
+        except IOError as e:
             pass
 
         if not found:
@@ -431,7 +431,7 @@ class Application(object):
             raise Exception("pycipres.conf doesn't contain all the required properties: %s" % ', '.join(requiredProperties))
         # if self.props.VERBOSE:
             # self.props.list()
-        print "URL=%s" % (self.props.URL)
+        print("URL=%s" % (self.props.URL))
 
     def getProperties(self):
         return self.props
@@ -487,22 +487,22 @@ def main():
         return 1
 
     except ValidationError as ve:
-        print ve.asString()
+        print(ve.asString())
         if verbose:
             raise
         return 1
     except CipresError as ce:
-        print "CIPRES ERROR: %s" % ( ce )
+        print("CIPRES ERROR: %s" % ( ce ))
         if verbose:
             raise
         return 1
     except requests.exceptions.RequestException as e:
-        print "CONNECTION ERROR: %s" % (e)
+        print("CONNECTION ERROR: %s" % (e))
         if verbose:
             raise 
         return 1
     except ET.ParseError as pe:
-        print "Unexpected response cannot be parsed.  Parsing error message: %s" % (pe)
+        print("Unexpected response cannot be parsed.  Parsing error message: %s" % (pe))
         if vervose:
             raise
         return 1
